-----------------------------------------------------------------------------------------------
-- Client Lua Script for AltStar
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- AltStar Module Definition
-----------------------------------------------------------------------------------------------
local AltStar = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999

local version = "0.5"
local printVersion = "empty"

local pairs = pairs
local tinsert = table.insert
-- --
local strGCurrentLocation = ""
local nGSessionCredits = 0
local bWndShow = false
local bNewSession = true 
-- --
local kStrClass =
{
	[GameLib.CodeEnumClass.Warrior] 		= Apollo.GetString("ClassWarrior"),
	[GameLib.CodeEnumClass.Engineer] 		= Apollo.GetString("ClassEngineer"),
	[GameLib.CodeEnumClass.Esper] 			= Apollo.GetString("ClassESPER"),
	[GameLib.CodeEnumClass.Medic] 			= Apollo.GetString("ClassMedic"),
	[GameLib.CodeEnumClass.Stalker] 		= Apollo.GetString("ClassStalker"),
	[GameLib.CodeEnumClass.Spellslinger] 	= Apollo.GetString("ClassSpellslinger"),
}

local kSprClass =
{
	[GameLib.CodeEnumClass.Warrior] 		= "IconSprites:Icon_Windows_UI_CRB_Warrior",
	[GameLib.CodeEnumClass.Engineer] 		= "IconSprites:Icon_Windows_UI_CRB_Engineer",
	[GameLib.CodeEnumClass.Esper] 			= "IconSprites:Icon_Windows_UI_CRB_Esper",
	[GameLib.CodeEnumClass.Medic] 			= "IconSprites:Icon_Windows_UI_CRB_Medic",
	[GameLib.CodeEnumClass.Stalker] 		= "IconSprites:Icon_Windows_UI_CRB_Stalker",
	[GameLib.CodeEnumClass.Spellslinger] 	= "IconSprites:Icon_Windows_UI_CRB_Spellslinger",
}

local kStrPath =
{
  [PlayerPathLib.PlayerPathType_Soldier]    = Apollo.GetString("PlayerPathSoldier"),
  [PlayerPathLib.PlayerPathType_Settler]    = Apollo.GetString("PlayerPathSettler"),
  [PlayerPathLib.PlayerPathType_Scientist]  = Apollo.GetString("PlayerPathScientist"),
  [PlayerPathLib.PlayerPathType_Explorer]   = Apollo.GetString("PlayerPathExplorer"),
}

local kSprPath =
{
  [PlayerPathLib.PlayerPathType_Soldier]    = "CRB_PlayerPathSprites:spr_Path_Soldier_Stretch",
  [PlayerPathLib.PlayerPathType_Settler]    = "CRB_PlayerPathSprites:spr_Path_Settler_Stretch",
  [PlayerPathLib.PlayerPathType_Scientist]  = "CRB_PlayerPathSprites:spr_Path_Scientist_Stretch",
  [PlayerPathLib.PlayerPathType_Explorer]   = "CRB_PlayerPathSprites:spr_Path_Explorer_Stretch",
}

local kStrFaction =
{
	[Unit.CodeEnumFaction.ExilesPlayer] 	= Apollo.GetString("CRB_Exile"),
	[Unit.CodeEnumFaction.DominionPlayer] 	= Apollo.GetString("CRB_Dominion"),
}

local kSprFaction =
{
	[Unit.CodeEnumFaction.ExilesPlayer] 	= "charactercreate:sprCharC_Ico_Exile_Lrg",
	[Unit.CodeEnumFaction.DominionPlayer] 	= "charactercreate:sprCharC_Ico_Dominion_Lrg",
}

local kclrWhite = ApolloColor.new("white")
local kclrRed 	= ApolloColor.new("ItemQuantityFull")

-- --



-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function AltStar:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here
	o.tData = 
	{
		settings 	= {},
		characters 	= {},
	}
	
	o.tCharacters 	= {}
	o.tInformation 	= {}
	o.tCurrency		= {}
	o.tMaterials 	= {}
	
	o.tSettings		= 
	{
		mainPos =
		{
			left	= 50,
			top		= 50,
			right 	= 610,
			bottom 	= 520,
		},
		trackerPos =
		{
			left	= 0,
			top		= 0,
			right 	= 250,
			bottom 	= 30,
		},
		bShowTracker 		= false,
		currencySelection 	= nil,
		version 			= self.version,
	}
	
	o.tListItemsCharacter 	= {}
	o.tListItemsMaterial 	= {}

    return o
end

function AltStar:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- AltStar OnLoad
-----------------------------------------------------------------------------------------------
function AltStar:OnLoad()

	self.playerUnit = GameLib.GetPlayerUnit()
	
	self.tListItemsCharacter = {}
	
	Apollo.RegisterEventHandler("VarChange_ZoneName", 					"OnChangeZoneName", self)
	Apollo.RegisterEventHandler("SubZoneChanged", 						"OnChangeZoneName", self)
	
	Apollo.RegisterEventHandler("InterfaceMenuListHasLoaded", "OnInterfaceMenuListHasLoaded", self)
	Apollo.RegisterEventHandler("ToggleAltStar", "OnToggleAltStar", self)

	Apollo.RegisterTimerHandler("OneSecTimer", "OnGathering", self)
	Apollo.RegisterTimerHandler("UpdateWindowInformation", "OnUpdateWindowInformation", self)
	Apollo.CreateTimer("UpdateWindowInformation", 0.5, true)
	Apollo.RegisterTimerHandler("UpdateTrackerInformation", "OnUpdateTrackerInformation", self)
	Apollo.CreateTimer("UpdateTrackerInformation", 0.5, true)
	
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("AltStar.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

function AltStar:OnSave(eLevel)		
	if eLevel ~= GameLib.CodeEnumAddonSaveLevel.Realm then	   
		return nil
    end

	local nLeft, nTop, nRight, nBottom = self.wndMain:GetAnchorOffsets()

	self.tSettings.mainPos.left 	= nLeft
	self.tSettings.mainPos.top 		= nTop
	self.tSettings.mainPos.right 	= nRight
	self.tSettings.mainPos.bottom 	= nBottom
	
	nLeft, nTop, nRight, nBottom = self.wndSessionTracker:GetAnchorOffsets()

	self.tSettings.trackerPos.left 		= nLeft
	self.tSettings.trackerPos.top 		= nTop
	self.tSettings.trackerPos.right 	= nRight
	self.tSettings.trackerPos.bottom 	= nBottom
	
	self.tSettings.version = version

	local tSave = 
	{
		characters = self.tCharacters,
		settings = self.tSettings,
	}
	
	return tSave
end

function AltStar:OnRestore(eLevel, tData)
	self.tData = tData
	
	-- Do not load data
	if self.tData.settings.version ~= version then
		return
	end
	
	self.tCharacters 	= self.tData.characters
	self.tSettings 		= self.tData.settings
	
	for k,v in pairs(self.tData.characters) do
		---self.tMaterials = self.tData.characters[k].materials
		---self.tInformation = self.tData.characters[k].information
		---self.tCurrencies = self.tData.characters[k].currencies
	end
end

-----------------------------------------------------------------------------------------------
-- AltStar OnDocLoaded
-----------------------------------------------------------------------------------------------
function AltStar:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "AltStarWindow", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
		self.wndSessionTracker 	= Apollo.LoadForm(self.xmlDoc, "AltStarSessionTracker", nil, self)
		self.wndCharacterList 	= self.wndMain:FindChild("ContainerCharacters")
		self.wndCreditOverview	= self.wndMain:FindChild("ContainerCredits")
		self.wndMaterialList 	= Apollo.LoadForm(self.xmlDoc, "ContainerMaterials", self.wndMain, self)
		
		self.wndMain:FindChild("BtnSessionTracker"):SetCheck(self.tSettings.bShowTracker)
		self.wndMain:FindChild("ContainerCurrencies:BtnSelCredits"):SetCheck(true)
		
		local mainPos		= self.tSettings.mainPos
		local trackerPos 	= self.tSettings.trackerPos		
		
		self.wndMain:SetAnchorOffsets(mainPos.left, mainPos.top, mainPos.right, mainPos.bottom)
		self.wndSessionTracker:SetAnchorOffsets(trackerPos.left, trackerPos.top, trackerPos.right, trackerPos.bottom)
		
		self.wndSessionTracker:Show(self.tSettings.bShowTracker, true)
		self.wndMaterialList:Show(false, true)
	    self.wndMain:Show(false, true)		

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("altstar", "OnSlashCommand", self)
		Apollo.RegisterSlashCommand("astar", "OnSlashCommand", self)
		Apollo.RegisterSlashCommand("as", "OnSlashCommand", self)

		-- Do additional Addon initialization here
	end
end

function AltStar:OnInterfaceMenuListHasLoaded()
	Event_FireGenericEvent("InterfaceMenuList_NewAddOn", "AltStar", {"ToggleAltStar", "", "CRB_Basekit:kitIcon_Holo_HazardProximity"})
end

function AltStar:OnToggleAltStar()
	if bWndShow then
		self:OnSlashCommand()
		bWndShow = false
	else
		self:OnCancel()
		bWndShow = true
	end	
end

-----------------------------------------------------------------------------------------------
-- AltStar Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

function AltStar:OnGathering()	
	self.playerUnit = GameLib.GetPlayerUnit()
	
	if self.playerUnit == nil then
		return
	end
	
	-- ------------------------------------------------------------
	--[[
	for name, data in pairs(self.tCharacters) do
		Print ("stored > "..name)		
	end
	
	Print (Unit.CodeEnumFaction.ExilesPlayer)
	Print ("----------")
	--]]
	-- ------------------------------------------------------------
	
	local strPlayerName = self.playerUnit:GetName()
	
	
	-- CHARACTER	
	self.tCharacters[strPlayerName] =
	{
		information = {},
		currencies 	= {},
		materials 	= {},
	}
	
	local nLevel		= self.playerUnit:GetLevel()
	local nClassId		= self.playerUnit:GetClassId()
	local nPathId		= self.playerUnit:GetPlayerPathType()
	local nFactionId 	= self.playerUnit:GetFaction()
	local strRealm		= GameLib.GetRealmName()
	local strLocation	= strGCurrentLocation
		
	self.tInformation =
	{
		level 		= nLevel,
		class		= nClassId,
		faction 	= nFactionId,
		path		= nPathId,
		realm		= strRealm,
		location 	= strLocation,
	}
	
	self.tCharacters[strPlayerName].information = self.tInformation
	
	-- CURRENCIES		
	local nCredits 		= GameLib.GetPlayerCurrency(Money.CodeEnumCurrencyType.Credits):GetAmount()
	local nRenown 		= GameLib.GetPlayerCurrency(Money.CodeEnumCurrencyType.Renown):GetAmount()	
	local nGems			= GameLib.GetPlayerCurrency(Money.CodeEnumCurrencyType.ElderGems):GetAmount()
	local nGlory 		= GameLib.GetPlayerCurrency(Money.CodeEnumCurrencyType.Glory):GetAmount()
	local nPrestige 	= GameLib.GetPlayerCurrency(Money.CodeEnumCurrencyType.Prestige):GetAmount()
	local nVouchers 	= GameLib.GetPlayerCurrency(Money.CodeEnumCurrencyType.CraftingVouchers):GetAmount()
	
	self.tCurrencies =
	{
		credits 	= nCredits,
		renown		= nRenown,
		gems 		= nGems,
		glory		= nGlory,
		prestige 	= nPrestige,
		vouchers 	= nVouchers,	
	}
	
	self.tCharacters[strPlayerName].currencies = self.tCurrencies
	
	-- MATERIALS
	local tSupplySatchel = self.playerUnit:GetSupplySatchelItems()
	
	for cat, mat in pairs(tSupplySatchel) do		
		local strCategory = cat		
		self.tMaterials[strCategory] = {}		
		
		for idx, obj in pairs(mat) do		
			local strMaterial = obj.itemMaterial:GetName()			
			self.tMaterials[strCategory][strMaterial] = { }			
			self.tMaterials[strCategory][strMaterial].count = obj.nCount
		end
	end
	
	self.tCharacters[strPlayerName].materials = self.tMaterials	
end

-- --

function AltStar:OnUpdateWindowInformation()

	if self.wndMain == nil or not self.wndMain:IsVisible() then
		return
	end

	local totalCreditsExile 	= 0
	local totalCreditsDominion 	= 0
	
	for name, data in pairs(self.tCharacters) do
		
		local c = self.tCharacters[name].currencies.credits
		
		if (self.tCharacters[name].information.faction == Unit.CodeEnumFaction.ExilesPlayer) then			
			totalCreditsExile = totalCreditsExile + c
			
			self.wndCreditOverview:FindChild("CreditsExile:Credits"):SetMoneySystem(Money.CodeEnumCurrencyType.Credits)
			self.wndCreditOverview:FindChild("CreditsExile:Credits"):SetAmount(totalCreditsExile)
		end		
		if (self.tCharacters[name].information.faction == Unit.CodeEnumFaction.DominionPlayer) then
			totalCreditsDominion = totalCreditsDominion + c
			
			self.wndCreditOverview:FindChild("CreditsDominion:Credits"):SetMoneySystem(Money.CodeEnumCurrencyType.Credits)
			self.wndCreditOverview:FindChild("CreditsDominion:Credits"):SetAmount(totalCreditsDominion)
		end
		
		self.wndMain:FindChild("OmniBits"):SetMoneySystem(Money.CodeEnumCurrencyType.GroupCurrency, 0, 0, AccountItemLib.CodeEnumAccountCurrency.Omnibits)
		self.wndMain:FindChild("OmniBits"):SetAmount(AccountItemLib.GetAccountCurrency(AccountItemLib.CodeEnumAccountCurrency.Omnibits):GetAmount())
		
		self.wndMain:FindChild("ServiceToken"):SetMoneySystem(Money.CodeEnumCurrencyType.GroupCurrency, 0, 0, AccountItemLib.CodeEnumAccountCurrency.ServiceToken)
		self.wndMain:FindChild("ServiceToken"):SetAmount(AccountItemLib.GetAccountCurrency(AccountItemLib.CodeEnumAccountCurrency.ServiceToken):GetAmount())
		
		self.wndMain:FindChild("FCoin"):SetMoneySystem(Money.CodeEnumCurrencyType.GroupCurrency, 0, 0, AccountItemLib.CodeEnumAccountCurrency.MysticShiny)
		self.wndMain:FindChild("FCoin"):SetAmount(AccountItemLib.GetAccountCurrency(AccountItemLib.CodeEnumAccountCurrency.MysticShiny):GetAmount())
		
		--[[
		if self.wndMain:FindChild("ContainerCurrencies:BtnSelOmni"):IsChecked() then
			--Print ("BtnSelOmni")
			wnd:FindChild("Currency"):SetMoneySystem(Money.CodeEnumCurrencyType.GroupCurrency, 0, 0, AccountItemLib.CodeEnumAccountCurrency.Omnibits)
			wnd:FindChild("Currency"):SetAmount(self.tCharacters[name].currencies.omnibits)		
		elseif self.wndMain:FindChild("ContainerCurrencies:BtnSelService"):IsChecked() then
			--Print ("BtnSelRenown")
			wnd:FindChild("Currency"):SetMoneySystem(Money.CodeEnumCurrencyType.GroupCurrency, 0, 0, AccountItemLib.CodeEnumAccountCurrency.ServiceToken)
			wnd:FindChild("Currency"):SetAmount(self.tCharacters[name].currencies.service)
		elseif self.wndMain:FindChild("ContainerCurrencies:BtnSelFCoin"):IsChecked() then
			--Print ("BtnSelRenown")
			wnd:FindChild("Currency"):SetMoneySystem(Money.CodeEnumCurrencyType.GroupCurrency, 0, 0, AccountItemLib.CodeEnumAccountCurrency.MysticShiny)
			wnd:FindChild("Currency"):SetAmount(self.tCharacters[name].currencies.coin)
		else
		--]] 
		
		local wnd = self.tListItemsCharacter[name]
		
		self:CurrencySelection()
		--wnd:FindChild("Currency"):SetAmount(c)
	end
end

function AltStar:OnUpdateTrackerInformation()

	if self.wndSessionTracker == nil and (not self.wndSessionTracker:IsVisible() or self.playerUnit == nil) then
		return
	end
	
	local sessionCredits 	= 0
	local currCredits 		= GameLib.GetPlayerCurrency(Money.CodeEnumCurrencyType.Credits):GetAmount()
	
	if bNewSession then
		nGSessionCredits = GameLib.GetPlayerCurrency(Money.CodeEnumCurrencyType.Credits):GetAmount()
		bNewSession = false
	end
	
	sessionCredits = currCredits - nGSessionCredits
	
	local scBuffer = sessionCredits
	
	if sessionCredits >= 0 then
		self.wndSessionTracker:FindChild("Credits"):SetTextColor(kclrWhite)
	else
		scBuffer = sessionCredits * (-1)
		self.wndSessionTracker:FindChild("Credits"):SetTextColor(kclrRed)
	end
	
	self.wndSessionTracker:FindChild("Credits"):SetMoneySystem(Money.CodeEnumCurrencyType.Credits)
	self.wndSessionTracker:FindChild("Credits"):SetAmount(scBuffer)
end

function AltStar:OnChangeZoneName(oVar, strZoneName)
	strGCurrentLocation = strZoneName
end

function AltStar:CurrencySelection()	
	for name, wnd in pairs(self.tListItemsCharacter) do	
		if self.wndMain:FindChild("ContainerCurrencies:BtnSelCredits"):IsChecked() then
			--Print ("BtnSelCredits")
			wnd:FindChild("Currency"):SetMoneySystem(Money.CodeEnumCurrencyType.Credits)
			wnd:FindChild("Currency"):SetAmount(self.tCharacters[name].currencies.credits)				
		elseif self.wndMain:FindChild("ContainerCurrencies:BtnSelRenown"):IsChecked() then
			--Print ("BtnSelRenown")
			wnd:FindChild("Currency"):SetMoneySystem(Money.CodeEnumCurrencyType.Renown)
			wnd:FindChild("Currency"):SetAmount(self.tCharacters[name].currencies.renown)	
		elseif self.wndMain:FindChild("ContainerCurrencies:BtnSelGem"):IsChecked() then
			--Print ("BtnSelGem")
			wnd:FindChild("Currency"):SetMoneySystem(Money.CodeEnumCurrencyType.ElderGems)
			wnd:FindChild("Currency"):SetAmount(self.tCharacters[name].currencies.gems)			
		
		elseif self.wndMain:FindChild("ContainerCurrencies:BtnSelGlory"):IsChecked() then
			--Print ("BtnSelGlory")
			wnd:FindChild("Currency"):SetMoneySystem(Money.CodeEnumCurrencyType.Glory)
			wnd:FindChild("Currency"):SetAmount(self.tCharacters[name].currencies.glory)		
		elseif self.wndMain:FindChild("ContainerCurrencies:BtnSelPrestige"):IsChecked() then
			--Print ("BtnSelPrestige")
			wnd:FindChild("Currency"):SetMoneySystem(Money.CodeEnumCurrencyType.Prestige)
			wnd:FindChild("Currency"):SetAmount(self.tCharacters[name].currencies.prestige)
		elseif self.wndMain:FindChild("ContainerCurrencies:BtnSelVoucher"):IsChecked() then
			--Print ("BtnSelVoucher")
			wnd:FindChild("Currency"):SetMoneySystem(Money.CodeEnumCurrencyType.CraftingVouchers)
			wnd:FindChild("Currency"):SetAmount(self.tCharacters[name].currencies.vouchers)		
		else
			--Print ("nuex")
		end
	end
end

-----------------------------------------------------------------------------------------------
-- AltStarForm Functions
-----------------------------------------------------------------------------------------------

-- ### CHARACTER LIST ###

-- POPULATE
function AltStar:PopulateCharacterList()

	self:DestroyCharacterListItems()
	
	local idx = 1

	for name, data in pairs(self.tCharacters) do
		local level 	= data.information.level
		local faction 	= data.information.faction
		local path 		= data.information.path
		local class		= data.information.class
		local location	= data.information.location		
		self:AddCharacterListItem(idx, name, level, faction, path, class, location)
		idx = idx + 1
	end	
	self.wndCharacterList:ArrangeChildrenVert()
end

-- ADD
function AltStar:AddCharacterListItem(idx, name, level, faction, path, class, location)
	
	local wnd = Apollo.LoadForm(self.xmlDoc, "ListItemCharacter", self.wndCharacterList, self)
	
	wnd:FindChild("LabelName"):SetText(name)
	if location == "" then
		wnd:FindChild("LabelLevel"):SetText("Lv "..tostring(level).." | "..kStrFaction[faction].." | "..kStrClass[class].." | "..kStrPath[path])
	else
		wnd:FindChild("LabelLevel"):SetText("Lv "..tostring(level).." | "..kStrFaction[faction].." | "..kStrClass[class].." | "..kStrPath[path].." | "..location)
	end
	
	self.tListItemsCharacter[name] = wnd
	
	--tinsert(self.tListItemsCharacter, wnd)
end

-- DESTROY
function AltStar:DestroyCharacterListItems()
	for k,v in pairs (self.tListItemsCharacter) do
		v:Destroy()
		self.tListItemsMaterial[k] = nil
	end
end

-- ###
-- ### MATERIAL LIST ###

-- POPULATE
function AltStar:PopulateMaterialList(wndControl)
	
	self:DestroyMaterialListItems()
	
	if self.tMaterials == nil then
		return
	end
	
	local wndData = wndControl:GetParent():GetId()
	
	local selCharacter = wndControl:GetParent():FindChild("LabelName"):GetText()
	
	-- DEBUG
	--Print (selCharacter)
	
	local tMat = self.tCharacters[selCharacter].materials
	
	for category, data in pairs(tMat) do
		local nCatCount = 0
		
		for k, v in pairs(data) do
			nCatCount = nCatCount + 1
		end		
		self:AddMaterialListItem(category, nCatCount, data)
	end
	
	self.wndMaterialList:FindChild("Title"):SetText("Materials")
	self.wndMaterialList:FindChild("Character"):SetText(selCharacter)
	self.wndMaterialList:FindChild("ContainerList"):ArrangeChildrenVert()
end

-- ADD
function AltStar:AddMaterialListItem(category, nCatCount, data)
	
	local wnd = Apollo.LoadForm(self.xmlDoc, "ListItemMaterial", self.wndMaterialList:FindChild("ContainerList"), self)
	
	wnd:FindChild("LabelCategory"):SetText(category)
	
	local bottomOffset = 20*(nCatCount+1)
	
	wnd:SetAnchorOffsets(0,0,295,bottomOffset)
	
	local offset = 20
	
	for material, amount in pairs (data) do
		local strMaterial = material
		local nCount = amount.count
		
		local entry = Apollo.LoadForm(self.xmlDoc, "ListItemMaterialEntry", wnd, self)
		if nCount == 250 then
			entry:FindChild("LabelAmount"):SetTextColor(kClrRed)
		else
		
		end		
		entry:FindChild("LabelAmount"):SetText(nCount)
		entry:FindChild("LabelName"):SetText(strMaterial)
		entry:SetAnchorOffsets(0,offset,192,offset+20)
		
		offset = offset + 20
	end		

	tinsert(self.tListItemsMaterial, wnd)	
end

-- DESTROY
function AltStar:DestroyMaterialListItems()
	for k,v in pairs (self.tListItemsMaterial) do
		v:Destroy()
	end
end

-- ###


-- ###

function AltStar:OnSlashCommand()
	self:PopulateCharacterList()
	self.wndMain:Invoke()
end

-- when the OK button is clicked
function AltStar:OnOK()
	self.wndMain:Close() -- hide the window
end

-- when the Cancel button is clicked
function AltStar:OnCancel()
	self.wndMain:Close() -- hide the window
end


---------------------------------------------------------------------------------------------------
-- ListItemCharacter Functions
---------------------------------------------------------------------------------------------------

function AltStar:OnMaterialListOpen( wndHandler, wndControl, eMouseButton )
	self:PopulateMaterialList(wndControl)
	self.wndMaterialList:Show(true)
end

---------------------------------------------------------------------------------------------------
-- ContainerMaterials Functions
---------------------------------------------------------------------------------------------------

function AltStar:OnMaterialListClose( wndHandler, wndControl, eMouseButton )
	self.wndMaterialList:Close()
end

---------------------------------------------------------------------------------------------------
-- AltStarWindow Functions
---------------------------------------------------------------------------------------------------

function AltStar:OnCharacterListRefresh( wndHandler, wndControl, eMouseButton )
	self:PopulateCharacterList()
end

function AltStar:OnSessionTrackerChange( wndHandler, wndControl, eMouseButton )
	self.tSettings.bShowTracker = self.wndMain:FindChild("BtnSessionTracker"):IsChecked()
	self.wndSessionTracker:Show(self.tSettings.bShowTracker)

function AltStar:OnCurrencySelection( wndHandler, wndControl, eMouseButton )
end

---------------------------------------------------------------------------------------------------
-- AltStarSessionTracker Functions
---------------------------------------------------------------------------------------------------
end
function AltStar:OnSessionReset( wndHandler, wndControl, eMouseButton, nLastRelativeMouseX, nLastRelativeMouseY, bDoubleClick, bStopPropagation )
	if (eMouseButton == 1) then
		bNewSession = true
	end
end

-----------------------------------------------------------------------------------------------
-- AltStar Instance
-----------------------------------------------------------------------------------------------
local AltStarInst = AltStar:new()
AltStarInst:Init()
